% ============================================================
%
% Solve_Hopf_with_PhaseDelay_New
%
% CBP 28-12-21 
% pkg load matgeom
%
% ============================================================

clear all;

global alpha mu omega phaseLag


pkg load matgeom;
pkg load signal;

clf; hold on;

tstart = 0;
tend = 50;

dT = 0.1;
alpha = 1;
omega = 1;
mu = 1;
phaseLag = (pi/180)*input('Input desired phse lag in degs ');
A = sqrt(mu);
AA = 1.5*A;
time = [0:dT:50];

% Specify the initial values of the neurons
uinit = [0.1,0,0,0,0,0];

% Set options for the calculation - do not change
options = odeset('RelTol',1e-6,'AbsTol',1e-6,'InitialStep',tend/1e4,'MaxStep',tend/1e4);
% start the calculation - do not change
printf(" --------------- calculating ----------- \n");
[t,u] = ode45(@rhs_Hopf_with_PhaseDelay,[tstart,tend],uinit,options);

% Get the neuron states
u1 = u(:,1);
u2 = u(:,2);
u5 = u(:,5);
u6 = u(:,6);

% subsample by factor 10
u1 = downsample(u1,10);
u2 = downsample(u2,10);
u5 = downsample(u5,10);
u6 = downsample(u6,10);
t = downsample(t,10);

printf(" --------------- plotting ----------- \n");

l1 = line(0,0,'color','r','linewidth',3);

% -------------- Figure setup-------------------
f1 = figure(1);
clf(f1);
sp1 = axes(f1);
axis(sp1,[-AA,AA,-AA,AA]);
axis('square');
 
title(sp1,'Phase Plane');
ylabel(sp1,'displacement');
xlabel(sp1,'velocity');
hold(sp1);

f2 = figure(2);
clf(f2);
sp2 = axes(f2);
axis(sp2,[0,max(time),-AA,AA]); 
  
title(sp2,'Displacement - time Plot');
xlabel(sp2,'time');
ylabel(sp2,'displacement');
hold(sp2);

% ---------------------------------------------

x1 = 0; y1 = 0;
x2 = 0; y2 = 0;

drawCircle(sp1,[0,0,A]);


i = 1;
while i < length(time) - 1

  drawCircle(sp1,[0,0,A],'g');

  x1Prev = x1;
  y1Prev = y1;
  x1 = u1(i);
  y1 = u2(i);
  
  x2Prev = x2;
  y2Prev = y2;
  x2 = u5(i);
  y2 = u6(i);
  
  
  plot(sp1,x1,y1,'r.','MarkerSize',20);
  plot(sp1,x1Prev,y1Prev,'w.','MarkerSize',20);    
  plot(sp1,x2,y2,'b.','MarkerSize',20);
  plot(sp1,x2Prev,y2Prev,'w.','MarkerSize',20);  
  plot(sp2,time(i),x1,'o');
  plot(sp2,time(i),x2,'o'); 
  drawnow;
  i++;
endwhile
